#
#	GammaScoutUtil - Tool to communicate with Gamma Scout Geiger counters.
#	Copyright (C) 2011-2011 Johannes Bauer
#	
#	This file is part of GammaScoutUtil.
#
#	GammaScoutUtil is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; this program is ONLY licensed under
#	version 3 of the License, later versions are explicitly excluded.
#
#	GammaScoutUtil is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with GammaScoutUtil; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Johannes Bauer <JohannesBauer@gmx.de>
#

class GSBasicSimData():
	_data = {
		"v": [ "", " Version 5.43" ],
		"b": [ 
			"",
			" GAMMA-SCOUT Protokoll ",
			"",
			" 0000 56 34 12 ff ff ff ff ff ff ff ff ff ff ff ff ff",			# Removed serial number for privacy
			" 0010 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0020 31 01 ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0030 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0040 ff ff ff ff ff ff ff ff de ad be ef ff ff ff ff",
			" 0050 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
		 	" 0060 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0070 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0080 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0090 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 00a0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 00b0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 00c0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 00d0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 00e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 00f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0100 fe 40 08 28 06 11 f2 04 07 03 ae 03 c6 ff 0f 00",
			" 0110 00 f8 f0 3c 22 3c 2a 3c 2a 3c 2f 3c 21 3c 1a 3c",
			" 0120 12 37 f4 37 ed 37 ee 3c 08 3c 05 3c 05 37 f7 37",
			" 0130 ff 02 da 02 ef 02 e3 02 bd 02 b6 02 fe 02 f4 02",
			" 0140 c6 02 ce 02 f6 02 db 02 e4 02 b9 02 e5 02 eb 02",
			" 0150 dd 02 eb 02 e6 02 e4 02 e4 02 bc 02 d3 02 e2 02",
			" 0160 a6 03 08 02 dd 02 d1 02 c9 02 bd 02 e1 03 03 03",
			" 0170 02 02 e2 02 e7 02 ee 02 da 02 e4 02 d3 02 e0 02",
			" 0180 f1 02 ef 02 d0 02 ba 02 d5 02 c0 03 0a 02 e4 02",
			" 0190 f0 02 ee 02 e8 02 be 02 f8 02 cd 02 c1 02 e7 02",
			" 01a0 f6 02 c7 02 ea 02 c8 02 f5 02 f0 02 c7 02 a2 02",
			" 01b0 e8 02 d8 03 03 02 d8 02 ee 02 cb 02 98 02 bb 02",
			" 01c0 bf 03 00 02 f7 03 23 02 c6 02 c3 02 e0 02 dd 02",
			" 01d0 d1 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 01e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 01f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0200 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0210 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0220 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0230 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0240 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0250 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0260 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0270 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0280 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0290 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 02a0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 02b0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 02c0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 02d0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 02e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 02f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0300 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0310 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0320 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0330 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0340 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0350 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0360 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0370 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0380 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0390 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 03a0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 03b0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 03c0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 03d0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 03e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 03f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0400 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0410 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0420 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0430 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0440 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0450 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0460 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0470 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0480 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0490 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 04a0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 04b0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 04c0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 04d0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 04e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 04f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0500 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0510 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0520 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0530 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0540 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0550 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0560 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0570 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0580 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0590 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 05a0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 05b0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 05c0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 05d0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 05e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 05f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0600 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0610 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0620 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0630 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0640 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0650 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0660 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0670 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0680 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0690 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 06a0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 06b0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 06c0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 06d0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 06e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 06f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0700 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0710 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0720 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0730 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0740 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0750 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0760 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0770 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0780 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 0790 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 07a0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 07b0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 07c0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 07d0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 07e0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
			" 07f0 ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff ff",
		],
		"z": [ "", " Protokollspeicher wieder frei " ],
		"d": [ "", " Datum gestellt " ],
		"u": [ "", " Zeit gestellt " ],
		"t": [ "", " AUS " ],
	}

	def __getitem__(self, key):
		return GSBasicSimData._data[key]
